var yyjson_8h =
[
    [ "yyjson_alc", "yyjson_8h.html#structyyjson__alc", [
      [ "malloc", "yyjson_8h.html#a83133b6b92e0fec52ec3c62538f44311", null ],
      [ "realloc", "yyjson_8h.html#affacb85df656149df6c07880f0ecbe95", null ],
      [ "free", "yyjson_8h.html#a2c770ff93f0f331bd60076eecd93661e", null ],
      [ "ctx", "yyjson_8h.html#ae9499246c39efd68c206280de1b31f45", null ]
    ] ],
    [ "yyjson_read_err", "yyjson_8h.html#structyyjson__read__err", [
      [ "code", "yyjson_8h.html#a550600110929a7030f464a460b5b62cb", null ],
      [ "msg", "yyjson_8h.html#a9044823fa7fb431019662e589d45707c", null ],
      [ "pos", "yyjson_8h.html#a87eb200779eff088b93ea0a67ab3e300", null ]
    ] ],
    [ "yyjson_write_err", "yyjson_8h.html#structyyjson__write__err", [
      [ "code", "yyjson_8h.html#ae4aa66c2b00d3173291dd48ae398b1c0", null ],
      [ "msg", "yyjson_8h.html#a3db87979e01ea1d86ce073b9e7218fe9", null ]
    ] ],
    [ "yyjson_arr_iter", "yyjson_8h.html#structyyjson__arr__iter", [
      [ "idx", "yyjson_8h.html#a1dbfcf575677cf45d7b1e1bef3de9c91", null ],
      [ "max", "yyjson_8h.html#a4c9dc89d29725de644b1d9b801aa28ff", null ],
      [ "cur", "yyjson_8h.html#a7445de186190ceef09c5be6d589e6a65", null ]
    ] ],
    [ "yyjson_obj_iter", "yyjson_8h.html#structyyjson__obj__iter", [
      [ "idx", "yyjson_8h.html#a6c2526c5ad89f0addaae26f356ecf609", null ],
      [ "max", "yyjson_8h.html#a05ac3955547a4be055542f922564ded6", null ],
      [ "cur", "yyjson_8h.html#af15973d5bdb6b7b8ea79571220771027", null ],
      [ "obj", "yyjson_8h.html#addf8b34eb1d89a54df0482acbd29872c", null ]
    ] ],
    [ "yyjson_mut_arr_iter", "yyjson_8h.html#structyyjson__mut__arr__iter", [
      [ "idx", "yyjson_8h.html#a2ed1833f97594ca751e4d079d1620e7a", null ],
      [ "max", "yyjson_8h.html#a1d8217217a7138d40e01752d3181ab85", null ],
      [ "cur", "yyjson_8h.html#a2498a5bf91ec2eb7d4a00f89dc465954", null ],
      [ "pre", "yyjson_8h.html#aa2481ee429a84f67e5f2200a4bbc6155", null ],
      [ "arr", "yyjson_8h.html#ad58dcd5f514d5f3c71412ec86af9e2d0", null ]
    ] ],
    [ "yyjson_mut_obj_iter", "yyjson_8h.html#structyyjson__mut__obj__iter", [
      [ "idx", "yyjson_8h.html#ad58bddcf6dd41d193d37d2a16df159d1", null ],
      [ "max", "yyjson_8h.html#aaf5c505b42eeb64e7a0ac17e3d7d3847", null ],
      [ "cur", "yyjson_8h.html#a4fc0b10196e010a7e5e9a2cec6769904", null ],
      [ "pre", "yyjson_8h.html#a934aea39ecf26ad163ad5dcf45cb8e6f", null ],
      [ "obj", "yyjson_8h.html#ab5169c5637fdfc27fe10b919b78b6468", null ]
    ] ],
    [ "yyjson_ptr_err", "yyjson_8h.html#structyyjson__ptr__err", [
      [ "code", "yyjson_8h.html#ac82ebe0c715ad673a943e784f325b538", null ],
      [ "msg", "yyjson_8h.html#a4d811ed5e9271667460dc1dc491d3295", null ],
      [ "pos", "yyjson_8h.html#a4b851ac068173fde6d305039762e33fd", null ]
    ] ],
    [ "yyjson_ptr_ctx", "yyjson_8h.html#structyyjson__ptr__ctx", [
      [ "ctn", "yyjson_8h.html#a9fabdf4380dc8f44f9b7479b54c75dd0", null ],
      [ "pre", "yyjson_8h.html#ac68fb5d2b48052c8ab3368d3ef6a6b81", null ],
      [ "old", "yyjson_8h.html#a4bd05d7a5f157f5178f97415c7ba08f7", null ]
    ] ],
    [ "yyjson_patch_err", "yyjson_8h.html#structyyjson__patch__err", [
      [ "code", "yyjson_8h.html#a96dab43e96fd2d54e26deb4c25792ab7", null ],
      [ "idx", "yyjson_8h.html#ac1584d63763ce24855df7aee5c9c5782", null ],
      [ "msg", "yyjson_8h.html#ae5741da19f51abd241bdce87a921ba4a", null ],
      [ "ptr", "yyjson_8h.html#a766102bcfc009fe568ea5655f133f753", null ]
    ] ],
    [ "yyjson_val_uni", "yyjson_8h.html#unionyyjson__val__uni", null ],
    [ "yyjson_val", "yyjson_8h.html#structyyjson__val", [
      [ "tag", "yyjson_8h.html#ab589c80e05e4e65fa28e23acc1ee8255", null ],
      [ "uni", "yyjson_8h.html#a3a07ac3ac97c66ae9b23efeab600d013", null ]
    ] ],
    [ "yyjson_doc", "yyjson_8h.html#structyyjson__doc", [
      [ "root", "yyjson_8h.html#ad22baac3e9ae0ff932b38f4257c3b800", null ],
      [ "alc", "yyjson_8h.html#ab1a7e03f48bb31760030fbdab7d6597b", null ],
      [ "dat_read", "yyjson_8h.html#a72bc53a422a133e2eba68ffa736f9e8b", null ],
      [ "val_read", "yyjson_8h.html#ac12f7aed42260b8d2ede0fded3f72167", null ],
      [ "str_pool", "yyjson_8h.html#a83e0a27da01978e46f074b6bb068d9eb", null ]
    ] ],
    [ "yyjson_mut_val", "yyjson_8h.html#structyyjson__mut__val", [
      [ "tag", "yyjson_8h.html#a5fd1ae5bada624c9687acce330eef7aa", null ],
      [ "uni", "yyjson_8h.html#a2f30e3958bf136b4e8453a0e78b43d0f", null ],
      [ "next", "yyjson_8h.html#a172090776a18e45190c933fb3294c07c", null ]
    ] ],
    [ "yyjson_str_chunk", "yyjson_8h.html#structyyjson__str__chunk", null ],
    [ "yyjson_str_pool", "yyjson_8h.html#structyyjson__str__pool", null ],
    [ "yyjson_val_chunk", "yyjson_8h.html#structyyjson__val__chunk", null ],
    [ "yyjson_val_pool", "yyjson_8h.html#structyyjson__val__pool", null ],
    [ "yyjson_mut_doc", "yyjson_8h.html#structyyjson__mut__doc", [
      [ "root", "yyjson_8h.html#a17d4291b05a54acc6310d16653de48b3", null ],
      [ "alc", "yyjson_8h.html#a1b6f74828e64779d450ffd0cbe61f08f", null ],
      [ "str_pool", "yyjson_8h.html#a11aa8b6fd06edf8fe371bae828052b39", null ],
      [ "val_pool", "yyjson_8h.html#a5607c9ba393206ad94ecd90fbeb59017", null ]
    ] ],
    [ "YYJSON_MSC_VER", "yyjson_8h.html#a77011c6b1268f9068abe1975b92e38e0", null ],
    [ "YYJSON_GCC_VER", "yyjson_8h.html#a0de4b27af40f104d2b1aac72edd6832e", null ],
    [ "YYJSON_IS_REAL_GCC", "yyjson_8h.html#a4781760a87346473a82f26fdd897fa52", null ],
    [ "YYJSON_STDC_VER", "yyjson_8h.html#a0a914f47b39417dd25fe728eef7d8f00", null ],
    [ "YYJSON_CPP_VER", "yyjson_8h.html#a2b6ed8ca435b89b44a9c66cad30fd9d5", null ],
    [ "yyjson_has_builtin", "yyjson_8h.html#a35f777885b981bd9caf1c24737b40921", null ],
    [ "yyjson_has_attribute", "yyjson_8h.html#ad7a6d7801cb0c35ee08fc6ba9d343106", null ],
    [ "yyjson_has_feature", "yyjson_8h.html#ae8f6fbea7b0eee0545bcf8d272ce7f33", null ],
    [ "yyjson_has_include", "yyjson_8h.html#afe50edcbf467f426784326f2282c51fd", null ],
    [ "yyjson_inline", "yyjson_8h.html#a45a5da162ba8a920163c74b71f48ead8", null ],
    [ "yyjson_noinline", "yyjson_8h.html#a07affd3b28fe93360627a1c4e03b5b88", null ],
    [ "yyjson_align", "yyjson_8h.html#a37185af21190fa0852a9b1ef9e041151", null ],
    [ "yyjson_likely", "yyjson_8h.html#a2fcd8be107f850c0d81ba7bff62edeb7", null ],
    [ "yyjson_unlikely", "yyjson_8h.html#a13065ff687cfd3b49eb38739676594f3", null ],
    [ "YYJSON_HAS_CONSTANT_P", "yyjson_8h.html#acf1b73925eff2306f4e23837cd874c8d", null ],
    [ "yyjson_deprecated", "yyjson_8h.html#af0cb2540fb4d4fc9809933a3020efaf8", null ],
    [ "yyjson_api", "yyjson_8h.html#a691136e772913e98860a791e65b70f04", null ],
    [ "yyjson_api_inline", "yyjson_8h.html#a682886dc8be2307076b125b496b15570", null ],
    [ "__bool_true_false_are_defined", "yyjson_8h.html#a665b0cc9ee2ced31785321d55cde349e", null ],
    [ "YYJSON_U64_TO_F64_NO_IMPL", "yyjson_8h.html#a39520db5ba6361257b7b51783357b877", null ],
    [ "YYJSON_VERSION_MAJOR", "yyjson_8h.html#a78cf6dd1700f2cd7d7f256b4c2339d8b", null ],
    [ "YYJSON_VERSION_MINOR", "yyjson_8h.html#a4c03e94b391df0f2b019c8df6c6e70f1", null ],
    [ "YYJSON_VERSION_PATCH", "yyjson_8h.html#aa6d66fc870aac34589593a0bf6561647", null ],
    [ "YYJSON_VERSION_HEX", "yyjson_8h.html#ac02a007abcdf7a80894f839acafa5963", null ],
    [ "YYJSON_VERSION_STRING", "yyjson_8h.html#a7b766ff66469615aab5bed9f760aab07", null ],
    [ "YYJSON_TYPE_NONE", "yyjson_8h.html#a1db6e43b1df0a46cee92d837ad553cc2", null ],
    [ "YYJSON_TYPE_RAW", "yyjson_8h.html#ae548138e539cfcebdfad39a58da44470", null ],
    [ "YYJSON_TYPE_NULL", "yyjson_8h.html#a3c003e6f71f42835957e6b9cf845a2e2", null ],
    [ "YYJSON_TYPE_BOOL", "yyjson_8h.html#a085018fbc0363aad32708fdf8b247e36", null ],
    [ "YYJSON_TYPE_NUM", "yyjson_8h.html#a720689b031a276a194e43c276fea9154", null ],
    [ "YYJSON_TYPE_STR", "yyjson_8h.html#a3a75e44d4e709fbfafa3137a15edbb68", null ],
    [ "YYJSON_TYPE_ARR", "yyjson_8h.html#a69ef1dad0f3735313d762050178ed320", null ],
    [ "YYJSON_TYPE_OBJ", "yyjson_8h.html#a79764d1a17bdd0a5b4f2b553a9d114b9", null ],
    [ "YYJSON_SUBTYPE_NONE", "yyjson_8h.html#a2a9e116a307c8dbcebc82305eca91fd3", null ],
    [ "YYJSON_SUBTYPE_FALSE", "yyjson_8h.html#a17877edf97bce2f3d7cf993cc9662a30", null ],
    [ "YYJSON_SUBTYPE_TRUE", "yyjson_8h.html#ae6a759cdc8865c891a89a67abd18a60e", null ],
    [ "YYJSON_SUBTYPE_UINT", "yyjson_8h.html#aa6a600891d4a3551b83a30afe576fd57", null ],
    [ "YYJSON_SUBTYPE_SINT", "yyjson_8h.html#ab5b72a76b60c408b8a7f2dfc31fbcbce", null ],
    [ "YYJSON_SUBTYPE_REAL", "yyjson_8h.html#a1efeaba2c4446788c9b30d20e1b82f73", null ],
    [ "YYJSON_SUBTYPE_NOESC", "yyjson_8h.html#af470523a4d0e9d89dfed5bcfae287bdb", null ],
    [ "YYJSON_TYPE_MASK", "yyjson_8h.html#a53b930a8e372ddd7c8d4d389caad391e", null ],
    [ "YYJSON_TYPE_BIT", "yyjson_8h.html#a9bc0cb130d1498238e942b93b8d8effd", null ],
    [ "YYJSON_SUBTYPE_MASK", "yyjson_8h.html#a7d15bc48e9734dab6620e35ec30cc348", null ],
    [ "YYJSON_SUBTYPE_BIT", "yyjson_8h.html#aa451fb3ba37fd42f69253e7d727836b7", null ],
    [ "YYJSON_RESERVED_MASK", "yyjson_8h.html#af44f401747d1fa6dd1b600c54de919ad", null ],
    [ "YYJSON_RESERVED_BIT", "yyjson_8h.html#a3aad1e39dcb4aec3e7e477500c220a53", null ],
    [ "YYJSON_TAG_MASK", "yyjson_8h.html#ac91eb401b770474ab76706ec58ac803d", null ],
    [ "YYJSON_TAG_BIT", "yyjson_8h.html#aa7acf05a1b4d7c04db1b09fffbedf35b", null ],
    [ "YYJSON_PADDING_SIZE", "yyjson_8h.html#abbe8e69f634b1a5a78c1dae08b88e0ef", null ],
    [ "YYJSON_WRITE_FP_FLAG_BITS", "yyjson_8h.html#a88948a21da1cda94c1e96e9f2c694d90", null ],
    [ "YYJSON_WRITE_FP_PREC_BITS", "yyjson_8h.html#ae661cccbf7206ef595909458768f11fd", null ],
    [ "YYJSON_WRITE_FP_TO_FIXED", "yyjson_8h.html#aa6456ada04bdbe304c1f3fb14e309ac6", null ],
    [ "YYJSON_WRITE_FP_TO_FLOAT", "yyjson_8h.html#ab1d81ddd4cc7bd198d537a7b6cd17ad3", null ],
    [ "yyjson_arr_foreach", "yyjson_8h.html#a60fd8094ee3eff6e7b629471f50aa139", null ],
    [ "yyjson_obj_foreach", "yyjson_8h.html#a32884e21b899ea5869b12aec02083002", null ],
    [ "yyjson_mut_arr_foreach", "yyjson_8h.html#a23a525f4192a237730aedfad55798fdb", null ],
    [ "yyjson_mut_obj_foreach", "yyjson_8h.html#ae3f12da3b11d3227dd517a1079065a3f", null ],
    [ "yyjson_type", "yyjson_8h.html#a4d30446a286f54e2f95847f3c6669493", null ],
    [ "yyjson_subtype", "yyjson_8h.html#a012fa5561c6c87879cceee4e0879a6b6", null ],
    [ "yyjson_read_flag", "yyjson_8h.html#a36af676813028c1360e8b343768f0e81", null ],
    [ "yyjson_read_code", "yyjson_8h.html#a0590c5ffcdd4f997a0ab5845ef624531", null ],
    [ "yyjson_incr_state", "yyjson_8h.html#a1961d8efe52ccb4f0de1c84f68f22e94", null ],
    [ "yyjson_write_flag", "yyjson_8h.html#afb7989387fc481f678e13325c18e6338", null ],
    [ "yyjson_write_code", "yyjson_8h.html#ae19102b96509817f1188f732be19642b", null ],
    [ "yyjson_ptr_code", "yyjson_8h.html#ac2f82adc891664bd3f7ef75591330e2f", null ],
    [ "yyjson_patch_code", "yyjson_8h.html#ad55a4435333880ce99fedf2aa82b7e46", null ],
    [ "yyjson_version", "yyjson_8h.html#a874f912f9c023bc353d1a770798017a1", null ],
    [ "yyjson_alc_pool_init", "yyjson_8h.html#a6068c4293a2b35493b18421b9afbd3d5", null ],
    [ "yyjson_alc_dyn_new", "yyjson_8h.html#a6a90ae91b82c2e8d6665a28a691eee18", null ],
    [ "yyjson_alc_dyn_free", "yyjson_8h.html#aaa9b7978e7b40e6d5d8d1cb3da0568d6", null ],
    [ "yyjson_locate_pos", "yyjson_8h.html#ac742b11ff26fb9af6362ffd2f3f21061", null ],
    [ "yyjson_read_opts", "yyjson_8h.html#acf234d21f0cb4b7fc89381ef25e9f0a8", null ],
    [ "yyjson_read_file", "yyjson_8h.html#a605ac08b083fb65331d7fa5eb5d32225", null ],
    [ "yyjson_read_fp", "yyjson_8h.html#a7f8c3918f8ab161bf7e2e203ff0f291e", null ],
    [ "yyjson_read", "yyjson_8h.html#aeab3c2a1d86225e5b181fb1bba7587d4", null ],
    [ "yyjson_incr_new", "yyjson_8h.html#a49c78bbfa5c961c1807d332f52d201f4", null ],
    [ "yyjson_incr_read", "yyjson_8h.html#adf5847c72fffb345de33667fd935097a", null ],
    [ "yyjson_incr_free", "yyjson_8h.html#a333bd893cdd22a379e2476e90b5532f2", null ],
    [ "yyjson_read_max_memory_usage", "yyjson_8h.html#ae511cac592355c2f60f170402b9d8dbf", null ],
    [ "yyjson_read_number", "yyjson_8h.html#a2b7dfa8495fb1d839e6294f2e7c4b58a", null ],
    [ "yyjson_mut_read_number", "yyjson_8h.html#aed1fdeb679986591d5f2f257c5cf3b60", null ],
    [ "yyjson_write_opts", "yyjson_8h.html#a43ccc01254525cef16699e72079e3e49", null ],
    [ "yyjson_write_file", "yyjson_8h.html#a2d82bd0dc78358326b03e28b9acc19e4", null ],
    [ "yyjson_write_fp", "yyjson_8h.html#a29eea00c04954094701bd90235a7073e", null ],
    [ "yyjson_write", "yyjson_8h.html#ad231975496ac3788fe5d69804e295443", null ],
    [ "yyjson_mut_write_opts", "yyjson_8h.html#a7af42d62aa1583986c687c5cd10b010e", null ],
    [ "yyjson_mut_write_file", "yyjson_8h.html#ad2a7aa77fa66a593536e3d7c3edb1d7a", null ],
    [ "yyjson_mut_write_fp", "yyjson_8h.html#ac8c17e7086a6d0a8db559ce0076c71e0", null ],
    [ "yyjson_mut_write", "yyjson_8h.html#a881e2ee3f487385810829df8bc675f1f", null ],
    [ "yyjson_val_write_opts", "yyjson_8h.html#a79720744960c9b4fdabbfb28379bbeb4", null ],
    [ "yyjson_val_write_file", "yyjson_8h.html#a725cc27bd7bd37c1d18c41589abd34db", null ],
    [ "yyjson_val_write_fp", "yyjson_8h.html#a3e5ad66dd43cc51500fff0926bae21a0", null ],
    [ "yyjson_val_write", "yyjson_8h.html#a00409eb59aee687f7778d00510b59d38", null ],
    [ "yyjson_mut_val_write_opts", "yyjson_8h.html#abdaf14b79fe803289070c0e5d5a705b8", null ],
    [ "yyjson_mut_val_write_file", "yyjson_8h.html#adf8b2d3c8b57e85d58108d58c68b0db5", null ],
    [ "yyjson_mut_val_write_fp", "yyjson_8h.html#acb80caf1bf1aecd6b68f38b84628c492", null ],
    [ "yyjson_mut_val_write", "yyjson_8h.html#a700da5ce5bf8bb9d3739cc73a0f51cdf", null ],
    [ "yyjson_write_number", "yyjson_8h.html#a26250087651ed3282ef31a27a0673333", null ],
    [ "yyjson_mut_write_number", "yyjson_8h.html#a9dec76e0a9d0c9e6039f2d15ec8b26fb", null ],
    [ "yyjson_doc_get_root", "yyjson_8h.html#aa33a13a85b840b3dbc1f8534db2bd8fc", null ],
    [ "yyjson_doc_get_read_size", "yyjson_8h.html#a33580e2537c25685fd1209951dcbc967", null ],
    [ "yyjson_doc_get_val_count", "yyjson_8h.html#a89cb55aebc946e462968a2bcace5ba5a", null ],
    [ "yyjson_doc_free", "yyjson_8h.html#adad98bd766cf52d99f2c54dcb120786d", null ],
    [ "yyjson_is_raw", "yyjson_8h.html#a286c610e7e27b8b4667a93eba2e2fa28", null ],
    [ "yyjson_is_null", "yyjson_8h.html#a81cc3185457d7fd86f3818319d7efe18", null ],
    [ "yyjson_is_true", "yyjson_8h.html#a527bfefae4532c4061e56d581ec4fc01", null ],
    [ "yyjson_is_false", "yyjson_8h.html#a6105e202bdb2e3b0bd1b561722b80afa", null ],
    [ "yyjson_is_bool", "yyjson_8h.html#a2e3dedcd83d286602101018024f21c52", null ],
    [ "yyjson_is_uint", "yyjson_8h.html#ac4b6eb9e397730bbb264f64d46cafacf", null ],
    [ "yyjson_is_sint", "yyjson_8h.html#ac3de217ef6c479380e38f35a2a166477", null ],
    [ "yyjson_is_int", "yyjson_8h.html#a5079543ec26e3634d0d97491195f0daf", null ],
    [ "yyjson_is_real", "yyjson_8h.html#a3cf0581ecad48a658da626cf86903f42", null ],
    [ "yyjson_is_num", "yyjson_8h.html#aedbd4efc6436d66382936b8c450a5877", null ],
    [ "yyjson_is_str", "yyjson_8h.html#a52f3358d27af0b1f1aeb3fe4dc7da1c0", null ],
    [ "yyjson_is_arr", "yyjson_8h.html#add7037998fb39b3e2d1b3caf59f9d66a", null ],
    [ "yyjson_is_obj", "yyjson_8h.html#affa9d4c51b9073804d91ef50e3f5ebd6", null ],
    [ "yyjson_is_ctn", "yyjson_8h.html#a01aace85ea46ac42974d86fb217a5086", null ],
    [ "yyjson_get_type", "yyjson_8h.html#a7d8d98b60284e646b8b22a8341d99a7f", null ],
    [ "yyjson_get_subtype", "yyjson_8h.html#a7435fee591b112fbdcc455fc60b1416b", null ],
    [ "yyjson_get_tag", "yyjson_8h.html#a022754b3eabf9ec15a4f8e9d52db015f", null ],
    [ "yyjson_get_type_desc", "yyjson_8h.html#a489b91cc6038a17ebc90193bc00e9e8b", null ],
    [ "yyjson_get_raw", "yyjson_8h.html#a5e90e838f969425f75372d4b4246d145", null ],
    [ "yyjson_get_bool", "yyjson_8h.html#aaed218041aa262337e179d487f4c770c", null ],
    [ "yyjson_get_uint", "yyjson_8h.html#ab439bc90f6631a67dd3ed4626eb3b4ad", null ],
    [ "yyjson_get_sint", "yyjson_8h.html#ac4aab52f91a8b365344a74812be4e712", null ],
    [ "yyjson_get_int", "yyjson_8h.html#a383b0a924785a30a49f6c59de235cd28", null ],
    [ "yyjson_get_real", "yyjson_8h.html#a5bfc74dbba137fc4d662702666f5073a", null ],
    [ "yyjson_get_num", "yyjson_8h.html#ac24ffc0726b50f38283c9f01f4e58d9b", null ],
    [ "yyjson_get_str", "yyjson_8h.html#a986e994db00b2749e000af0a4331454c", null ],
    [ "yyjson_get_len", "yyjson_8h.html#ae4b5e4edc9713d9f48e2a6750ad5ebff", null ],
    [ "yyjson_equals_str", "yyjson_8h.html#a147b5b874e6b939731f1b6c15abcbbca", null ],
    [ "yyjson_equals_strn", "yyjson_8h.html#a1a7a91be15978b45345976c8432769aa", null ],
    [ "yyjson_equals", "yyjson_8h.html#adabd9eb44fac843109d6bc79f12ff6ff", null ],
    [ "yyjson_set_raw", "yyjson_8h.html#a75ee22602fb750b67fda804fb653ef1e", null ],
    [ "yyjson_set_null", "yyjson_8h.html#a079fdf2d481492c8533104437dbf2283", null ],
    [ "yyjson_set_bool", "yyjson_8h.html#ad99ceda574b466f8102699e52564c8da", null ],
    [ "yyjson_set_uint", "yyjson_8h.html#a90614444c9d6bbd7d8586176986adbc5", null ],
    [ "yyjson_set_sint", "yyjson_8h.html#ad0f58bd6ac0289fd55d09b02fa3d4743", null ],
    [ "yyjson_set_int", "yyjson_8h.html#af1f4dd90c0bd891cb139e72cfd588789", null ],
    [ "yyjson_set_float", "yyjson_8h.html#aae763338f1c11ad9da6be1cf522daf6e", null ],
    [ "yyjson_set_double", "yyjson_8h.html#acfc9cec2bb59669d777fe219730793b8", null ],
    [ "yyjson_set_real", "yyjson_8h.html#ac782a838c6378f022434d7ab3a3b333d", null ],
    [ "yyjson_set_fp_to_fixed", "yyjson_8h.html#a1f72379c8ef022cbe6ad815101c8acec", null ],
    [ "yyjson_set_fp_to_float", "yyjson_8h.html#a0705e92b9d45c609be958ec7f2351900", null ],
    [ "yyjson_set_str", "yyjson_8h.html#a9a0f4082d2244b7264a819bbc32ebbdf", null ],
    [ "yyjson_set_strn", "yyjson_8h.html#a9e49dc52b6209708df0ccf4ddf49b8c4", null ],
    [ "yyjson_set_str_noesc", "yyjson_8h.html#a44386e6e1084aaea376238723bd11d74", null ],
    [ "yyjson_arr_size", "yyjson_8h.html#a0ea8514c92f39fd93ddcbe93a7f466e5", null ],
    [ "yyjson_arr_get", "yyjson_8h.html#ac709738fbf9da708c28992c40746fcbf", null ],
    [ "yyjson_arr_get_first", "yyjson_8h.html#ad54c34d490dd8e479e21e4cb29bc814b", null ],
    [ "yyjson_arr_get_last", "yyjson_8h.html#a15bbce96107aa455670ebe9aab98964d", null ],
    [ "yyjson_arr_iter_init", "yyjson_8h.html#a95aebc83fff9793f7701a6e37df5e03f", null ],
    [ "yyjson_arr_iter_with", "yyjson_8h.html#a38b10c3293b817b25d9dd985da121cb5", null ],
    [ "yyjson_arr_iter_has_next", "yyjson_8h.html#a216b976b352fe001d580fe837a844e79", null ],
    [ "yyjson_arr_iter_next", "yyjson_8h.html#ab608a351427921421a2e23877399acd5", null ],
    [ "yyjson_obj_size", "yyjson_8h.html#aa9789f197f972dc433ea2eb622defd50", null ],
    [ "yyjson_obj_get", "yyjson_8h.html#a1e8a4dea2e9e9248acde14c664ab702b", null ],
    [ "yyjson_obj_getn", "yyjson_8h.html#a2936ca2492ae8cdcdf0435f5259ff854", null ],
    [ "yyjson_obj_iter_init", "yyjson_8h.html#a2b6a426ece4ffeb9dede1f7a9970140d", null ],
    [ "yyjson_obj_iter_with", "yyjson_8h.html#a543806a566821ccc6c7069edabc59a85", null ],
    [ "yyjson_obj_iter_has_next", "yyjson_8h.html#ab83087bafd1f48910b62bf63200679e1", null ],
    [ "yyjson_obj_iter_next", "yyjson_8h.html#a6033befb82b9331d2c19c09799ec5bcf", null ],
    [ "yyjson_obj_iter_get_val", "yyjson_8h.html#a3403b9c25c8b8f2b3027f4e6d97d0ca8", null ],
    [ "yyjson_obj_iter_get", "yyjson_8h.html#a1f3b09c4f279287f8af93b3754a41e85", null ],
    [ "yyjson_obj_iter_getn", "yyjson_8h.html#a7a45a4b5a1340bb3c2907b7faf3981be", null ],
    [ "yyjson_mut_doc_get_root", "yyjson_8h.html#aa33ac310f363ace5f4dda3697b2c0123", null ],
    [ "yyjson_mut_doc_set_root", "yyjson_8h.html#a8a9f7ea865526acb97ee4eff8d0bb79f", null ],
    [ "yyjson_mut_doc_set_str_pool_size", "yyjson_8h.html#aec93f33123755af4dfa25c1335a44184", null ],
    [ "yyjson_mut_doc_set_val_pool_size", "yyjson_8h.html#a9dd1f854542f298e963f0912a5a0e002", null ],
    [ "yyjson_mut_doc_free", "yyjson_8h.html#a7a5f504993031f912d06777b8a7b5aff", null ],
    [ "yyjson_mut_doc_new", "yyjson_8h.html#ae27cb375110302ec19f4376d7cab3c5b", null ],
    [ "yyjson_doc_mut_copy", "yyjson_8h.html#a083356ecb65e45453033285f3d836de9", null ],
    [ "yyjson_mut_doc_mut_copy", "yyjson_8h.html#a6ee1dc133fa773528286cd0b25300cb2", null ],
    [ "yyjson_val_mut_copy", "yyjson_8h.html#a04ff184b833fe2d6932309821e2b2e5a", null ],
    [ "yyjson_mut_val_mut_copy", "yyjson_8h.html#a66761be40cfb010086ec798ddb44018f", null ],
    [ "yyjson_mut_doc_imut_copy", "yyjson_8h.html#a797642b2f815a4f05db03ef87f08cc4f", null ],
    [ "yyjson_mut_val_imut_copy", "yyjson_8h.html#a7a142af553e7831989593aee44f74e26", null ],
    [ "yyjson_mut_is_raw", "yyjson_8h.html#a2bbea1da400b473e92b8429027d0f307", null ],
    [ "yyjson_mut_is_null", "yyjson_8h.html#a17fda97923bb434d4214c56534586606", null ],
    [ "yyjson_mut_is_true", "yyjson_8h.html#a5c94af000c170272356f060c76f91559", null ],
    [ "yyjson_mut_is_false", "yyjson_8h.html#aadb5f3196fe14e75914ed34d6e700076", null ],
    [ "yyjson_mut_is_bool", "yyjson_8h.html#ad18730f04c429faa79be473de57efd5e", null ],
    [ "yyjson_mut_is_uint", "yyjson_8h.html#a740d49152b7b9974c65efeab698dfb67", null ],
    [ "yyjson_mut_is_sint", "yyjson_8h.html#a907fa46c6ab95e9d7652392507f17e3b", null ],
    [ "yyjson_mut_is_int", "yyjson_8h.html#a7bb8c32c190a8e4ce4f5e9e95623f304", null ],
    [ "yyjson_mut_is_real", "yyjson_8h.html#acfc8545d9b1af8dd8f1488e34fbac351", null ],
    [ "yyjson_mut_is_num", "yyjson_8h.html#a4c37c92b9977d86475cda1884c9ae52e", null ],
    [ "yyjson_mut_is_str", "yyjson_8h.html#ad9f16424bfef46cd479066905f653591", null ],
    [ "yyjson_mut_is_arr", "yyjson_8h.html#a538974615c719cb8ea2e8ea7705569cf", null ],
    [ "yyjson_mut_is_obj", "yyjson_8h.html#aaafe8a57b5e53c9f7f9984c80ab3be1f", null ],
    [ "yyjson_mut_is_ctn", "yyjson_8h.html#a25f0e04af88792dd01e0ed8461ffb51b", null ],
    [ "yyjson_mut_get_type", "yyjson_8h.html#a69acff4e2298d6b1a315d5f75a5eaa9d", null ],
    [ "yyjson_mut_get_subtype", "yyjson_8h.html#a1a032ed912524326d22331f7dd1366f2", null ],
    [ "yyjson_mut_get_tag", "yyjson_8h.html#a64603b1c33c9ebc626665dea61e25abd", null ],
    [ "yyjson_mut_get_type_desc", "yyjson_8h.html#a0718192e8eb1b46a83116b15ce6e67c7", null ],
    [ "yyjson_mut_get_raw", "yyjson_8h.html#a3de6970785ebf0dd000d28c916793388", null ],
    [ "yyjson_mut_get_bool", "yyjson_8h.html#a5ae266ef7d5c52eaa2d5afeafab41721", null ],
    [ "yyjson_mut_get_uint", "yyjson_8h.html#a708869e986c30d3a03026be8ce4c2b37", null ],
    [ "yyjson_mut_get_sint", "yyjson_8h.html#af9824de7303491b4e43dd423878ae0a0", null ],
    [ "yyjson_mut_get_int", "yyjson_8h.html#aad6de220fa487e31bd1bd2c2cccd9bff", null ],
    [ "yyjson_mut_get_real", "yyjson_8h.html#addde26cc012f50aee79a623e6be4614e", null ],
    [ "yyjson_mut_get_num", "yyjson_8h.html#ae46242b9ad367c677a5026f6ea30c635", null ],
    [ "yyjson_mut_get_str", "yyjson_8h.html#a896424a210ec4983f0634467ebe85a68", null ],
    [ "yyjson_mut_get_len", "yyjson_8h.html#aec3a6e6812f3ca8fd58c858275443fe0", null ],
    [ "yyjson_mut_equals_str", "yyjson_8h.html#ab2c44c43c9e8ff194799fd59ae688ee2", null ],
    [ "yyjson_mut_equals_strn", "yyjson_8h.html#a1887a4e64900348851f22d528950bf7e", null ],
    [ "yyjson_mut_equals", "yyjson_8h.html#ab0a5c5a568b7f2c0a6301149f0f6aa84", null ],
    [ "yyjson_mut_set_raw", "yyjson_8h.html#a510bd8af8c64911827c890bd67245282", null ],
    [ "yyjson_mut_set_null", "yyjson_8h.html#a6e0c3b9ff069db64e4aa14da1078b538", null ],
    [ "yyjson_mut_set_bool", "yyjson_8h.html#a108d97873650fd95453f3c82a0b6a2aa", null ],
    [ "yyjson_mut_set_uint", "yyjson_8h.html#a84604772b235ec0f651532013f2480a8", null ],
    [ "yyjson_mut_set_sint", "yyjson_8h.html#ad3c513a8fd61c173c4afa404572e02f6", null ],
    [ "yyjson_mut_set_int", "yyjson_8h.html#a64168360e4ac45070f98c6db92b89cd7", null ],
    [ "yyjson_mut_set_float", "yyjson_8h.html#a22cb5a0c2cfd20893de76ef77a785627", null ],
    [ "yyjson_mut_set_double", "yyjson_8h.html#a185b931c987bc80325339ab7369753c6", null ],
    [ "yyjson_mut_set_real", "yyjson_8h.html#a0cbd041b4d5a31d6dcc0bd759eae6cf7", null ],
    [ "yyjson_mut_set_fp_to_fixed", "yyjson_8h.html#a0c58c31c80202d83c1c2d3bd69e3bf72", null ],
    [ "yyjson_mut_set_fp_to_float", "yyjson_8h.html#a1568c53a68914a5660a50490232737ac", null ],
    [ "yyjson_mut_set_str", "yyjson_8h.html#a84e98fae940ff675b2a22076cbd5efc1", null ],
    [ "yyjson_mut_set_strn", "yyjson_8h.html#a298c4558e0b349e4f801f210f19ac8b1", null ],
    [ "yyjson_mut_set_str_noesc", "yyjson_8h.html#acaf2da602f21785dbacc66661f89a570", null ],
    [ "yyjson_mut_set_arr", "yyjson_8h.html#af6dac7e5e95ccc12d79c31b96d33940a", null ],
    [ "yyjson_mut_set_obj", "yyjson_8h.html#a533791670fe27f71bab321d586e11ea2", null ],
    [ "yyjson_mut_raw", "yyjson_8h.html#a7541eb4eadf59e84f1ef06889789d460", null ],
    [ "yyjson_mut_rawn", "yyjson_8h.html#a3f69c2e1cdc99ae4f9914435b7a542d7", null ],
    [ "yyjson_mut_rawcpy", "yyjson_8h.html#a35cfc3e94310aaddb9eaf6609c4640d9", null ],
    [ "yyjson_mut_rawncpy", "yyjson_8h.html#a8a9cc40b5f3f93b66ba191449f81fbda", null ],
    [ "yyjson_mut_null", "yyjson_8h.html#a73e0044fd0c511263cbf5cd869976475", null ],
    [ "yyjson_mut_true", "yyjson_8h.html#a032637dbdee5a6525420384daa097dff", null ],
    [ "yyjson_mut_false", "yyjson_8h.html#a184a7d8fa5b929ce01c7181712c34747", null ],
    [ "yyjson_mut_bool", "yyjson_8h.html#a57afc80d0c89c0ae20d5ff183f3a8205", null ],
    [ "yyjson_mut_uint", "yyjson_8h.html#a893a09172b402af1bf520cf7347dfeab", null ],
    [ "yyjson_mut_sint", "yyjson_8h.html#acd434c1a97d275f97f743e47e228831a", null ],
    [ "yyjson_mut_int", "yyjson_8h.html#a92e202b3738250ffee612089bdec91eb", null ],
    [ "yyjson_mut_float", "yyjson_8h.html#a3497c331c3a3746dab89e20a38c5daa0", null ],
    [ "yyjson_mut_double", "yyjson_8h.html#a97fb1056954960e76be19e33dc5b6df0", null ],
    [ "yyjson_mut_real", "yyjson_8h.html#a177181eee333314c7b40e2dc573fcdec", null ],
    [ "yyjson_mut_str", "yyjson_8h.html#ae8d7e4c75adb1b9adb2246165491a4a3", null ],
    [ "yyjson_mut_strn", "yyjson_8h.html#a13c39f37c6936907c266ba9c076dd741", null ],
    [ "yyjson_mut_strcpy", "yyjson_8h.html#a95300bcf1cdb52d296e39aa1a4650741", null ],
    [ "yyjson_mut_strncpy", "yyjson_8h.html#a1588bdc6f4125e5c6d1daf6b240f6ff8", null ],
    [ "yyjson_mut_arr_size", "yyjson_8h.html#a847bb374b9c7fa6fff34088d23d87dad", null ],
    [ "yyjson_mut_arr_get", "yyjson_8h.html#a08b69c78024de357ed49abcc19d5b2f3", null ],
    [ "yyjson_mut_arr_get_first", "yyjson_8h.html#a9ff667f95ec6e6e264509e1681c74357", null ],
    [ "yyjson_mut_arr_get_last", "yyjson_8h.html#a8f6ad942e4ba4d3fb7cb52459af708a6", null ],
    [ "yyjson_mut_arr_iter_init", "yyjson_8h.html#ad88b6743f333d9e4eff04b0138619e74", null ],
    [ "yyjson_mut_arr_iter_with", "yyjson_8h.html#a9d8bf48b287cc0099eb6619d8b4b712e", null ],
    [ "yyjson_mut_arr_iter_has_next", "yyjson_8h.html#a214c115652630e5acaa9fa062844e0c9", null ],
    [ "yyjson_mut_arr_iter_next", "yyjson_8h.html#a793250c5394193a73b5e9506c8381994", null ],
    [ "yyjson_mut_arr_iter_remove", "yyjson_8h.html#a20fa69856e99295473e1b3e111adc3b1", null ],
    [ "yyjson_mut_arr", "yyjson_8h.html#aec0e874c4847338f3b61bf46257cb557", null ],
    [ "yyjson_mut_arr_with_bool", "yyjson_8h.html#afd2b114767b989006259409c6955bb37", null ],
    [ "yyjson_mut_arr_with_sint", "yyjson_8h.html#a05771fb3cd9c9d2f854dc9528feac58a", null ],
    [ "yyjson_mut_arr_with_uint", "yyjson_8h.html#ab2237deb1190a0333a88d571a8adcb0c", null ],
    [ "yyjson_mut_arr_with_real", "yyjson_8h.html#a7173b66e47ee6fad38b11651d20e7ddf", null ],
    [ "yyjson_mut_arr_with_sint8", "yyjson_8h.html#ab9c7f452ed21a9800501c25e715f35f7", null ],
    [ "yyjson_mut_arr_with_sint16", "yyjson_8h.html#a72bd3b0467273c40dbe376bc7c0a8f06", null ],
    [ "yyjson_mut_arr_with_sint32", "yyjson_8h.html#a54bfa0c027fb21e9e5c33a9f4ecbe0f5", null ],
    [ "yyjson_mut_arr_with_sint64", "yyjson_8h.html#a37d0c7987b2958550076586ca36082fd", null ],
    [ "yyjson_mut_arr_with_uint8", "yyjson_8h.html#a2ae7e73e8a1431554d621059b06222e6", null ],
    [ "yyjson_mut_arr_with_uint16", "yyjson_8h.html#a85f4bcdc777cde51a40359ac9e38c98b", null ],
    [ "yyjson_mut_arr_with_uint32", "yyjson_8h.html#ac24336d6f29b5b6c09f513373b6fc83e", null ],
    [ "yyjson_mut_arr_with_uint64", "yyjson_8h.html#aae70fe76dfae0e8aa93d0226ec8510d9", null ],
    [ "yyjson_mut_arr_with_float", "yyjson_8h.html#a50039175677ae5fdd51f1c6942fa3d3d", null ],
    [ "yyjson_mut_arr_with_double", "yyjson_8h.html#ac81702a782ecfeb9874ce43706ecf02e", null ],
    [ "yyjson_mut_arr_with_str", "yyjson_8h.html#af7da1562cde867338bc69395c2aeb0ad", null ],
    [ "yyjson_mut_arr_with_strn", "yyjson_8h.html#a419008c4a6f2dc4221211b0d7770109a", null ],
    [ "yyjson_mut_arr_with_strcpy", "yyjson_8h.html#a90c3e1c55dcf04a7879abed9a57cb278", null ],
    [ "yyjson_mut_arr_with_strncpy", "yyjson_8h.html#ad8c68a8cec010d2d5f8942eb1136afde", null ],
    [ "yyjson_mut_arr_insert", "yyjson_8h.html#ae0898f45c9fca1d7d6bdd35b3488a10f", null ],
    [ "yyjson_mut_arr_append", "yyjson_8h.html#af089d7f9bfb1b4fadf46073a534379b0", null ],
    [ "yyjson_mut_arr_prepend", "yyjson_8h.html#a1557f6dca4e03380449cb9b5f043f699", null ],
    [ "yyjson_mut_arr_replace", "yyjson_8h.html#a33704c7475fcdbc8ce7504e9b9756b16", null ],
    [ "yyjson_mut_arr_remove", "yyjson_8h.html#a26d9cd39957b06085492ec7050850a19", null ],
    [ "yyjson_mut_arr_remove_first", "yyjson_8h.html#af7484aeed9b789103efb985f2f42ab46", null ],
    [ "yyjson_mut_arr_remove_last", "yyjson_8h.html#a923bc9e3c4af69b5bdb5361a9f0a4ba5", null ],
    [ "yyjson_mut_arr_remove_range", "yyjson_8h.html#ab96f33fef20cadcb9bb045c60749b516", null ],
    [ "yyjson_mut_arr_clear", "yyjson_8h.html#a274fc7be14bed93794e3e720927f7bc5", null ],
    [ "yyjson_mut_arr_rotate", "yyjson_8h.html#a6df6d46adbd674a53cbfc049d49ec5c5", null ],
    [ "yyjson_mut_arr_add_val", "yyjson_8h.html#ab361240999d684579904a9aa3af5004f", null ],
    [ "yyjson_mut_arr_add_null", "yyjson_8h.html#afb1e130c69db1f54e924e82c3d6377c9", null ],
    [ "yyjson_mut_arr_add_true", "yyjson_8h.html#a125859d255ca67ed339fbf3d05539c94", null ],
    [ "yyjson_mut_arr_add_false", "yyjson_8h.html#a930a47cf837316e3758e38057178edac", null ],
    [ "yyjson_mut_arr_add_bool", "yyjson_8h.html#a5c7fae9804b126005f99c67f3c703ad5", null ],
    [ "yyjson_mut_arr_add_uint", "yyjson_8h.html#a6efba736a610baa629bf2a0b0a41d4a9", null ],
    [ "yyjson_mut_arr_add_sint", "yyjson_8h.html#ab459a079674a115123c353441dacda22", null ],
    [ "yyjson_mut_arr_add_int", "yyjson_8h.html#ad20aad460c6d7c62f7c371ca5be54667", null ],
    [ "yyjson_mut_arr_add_float", "yyjson_8h.html#ab07c81d726e44806b918481becf7f6d3", null ],
    [ "yyjson_mut_arr_add_double", "yyjson_8h.html#a39283533d6fee8d33eb0e3b818ce8fee", null ],
    [ "yyjson_mut_arr_add_real", "yyjson_8h.html#aa47704ca9b08cdd7b8b151ec67c4afd6", null ],
    [ "yyjson_mut_arr_add_str", "yyjson_8h.html#a09acbadaf1d791167a277ed35540577b", null ],
    [ "yyjson_mut_arr_add_strn", "yyjson_8h.html#a97b82f92bd96415090ce9803b9757bf9", null ],
    [ "yyjson_mut_arr_add_strcpy", "yyjson_8h.html#a2877858de77e7765ef44d8659eb7fcd3", null ],
    [ "yyjson_mut_arr_add_strncpy", "yyjson_8h.html#a158fecc9fb751aeb56472844321bdfab", null ],
    [ "yyjson_mut_arr_add_arr", "yyjson_8h.html#a8e0dfe2ac2a53faadf137d159162d193", null ],
    [ "yyjson_mut_arr_add_obj", "yyjson_8h.html#acd2884309c99b42f916fffd50c018c59", null ],
    [ "yyjson_mut_obj_size", "yyjson_8h.html#a601ac20666dd26bfbec016ee4cbb1b92", null ],
    [ "yyjson_mut_obj_get", "yyjson_8h.html#a90a824479a3d07f47e9bcce9bbbfcdc0", null ],
    [ "yyjson_mut_obj_getn", "yyjson_8h.html#a9f40302607516131c026ca5f13a29946", null ],
    [ "yyjson_mut_obj_iter_init", "yyjson_8h.html#ad32e0e0427bda63164f12fe689a6f854", null ],
    [ "yyjson_mut_obj_iter_with", "yyjson_8h.html#aedac207e6c2d5e031997e2b0df73db6a", null ],
    [ "yyjson_mut_obj_iter_has_next", "yyjson_8h.html#aca1345f5057068e556cc6fadda10d04c", null ],
    [ "yyjson_mut_obj_iter_next", "yyjson_8h.html#a55f4228c2d65d497ad3cee8abe95c0be", null ],
    [ "yyjson_mut_obj_iter_get_val", "yyjson_8h.html#aaa4bef14b71ff145fe8cdc2fa98c7f45", null ],
    [ "yyjson_mut_obj_iter_remove", "yyjson_8h.html#a6e891b4020dd6325d6eacb5e108da3c4", null ],
    [ "yyjson_mut_obj_iter_get", "yyjson_8h.html#a9e79f1480256c6e2e8dfbf61da9cd853", null ],
    [ "yyjson_mut_obj_iter_getn", "yyjson_8h.html#a3d3ab359890ab167041732a871ab943d", null ],
    [ "yyjson_mut_obj", "yyjson_8h.html#a721dacf0e32ee6c7f18817aca806e9b2", null ],
    [ "yyjson_mut_obj_with_str", "yyjson_8h.html#a49cfc79051b729689f4f08592b284cc9", null ],
    [ "yyjson_mut_obj_with_kv", "yyjson_8h.html#afc2749d9ed694b6d0a4f5c14da19c7d4", null ],
    [ "yyjson_mut_obj_add", "yyjson_8h.html#ac0e1bcd9f449e4b1e62d25fb96830a62", null ],
    [ "yyjson_mut_obj_put", "yyjson_8h.html#acbfde7c1173b4258f83029c6dacf47c3", null ],
    [ "yyjson_mut_obj_insert", "yyjson_8h.html#a98e9f97614fce2a6187473eeb35274e8", null ],
    [ "yyjson_mut_obj_remove", "yyjson_8h.html#a660d533ce8b661e85c5b14e4e99e5085", null ],
    [ "yyjson_mut_obj_remove_key", "yyjson_8h.html#a13d5da22b245b8242d9c5c6bd6b3582b", null ],
    [ "yyjson_mut_obj_remove_keyn", "yyjson_8h.html#a36b5cade5e5cfecd47e9ae584078e2b4", null ],
    [ "yyjson_mut_obj_clear", "yyjson_8h.html#aee5bc7d2ad2169a04f54e63139eddb86", null ],
    [ "yyjson_mut_obj_replace", "yyjson_8h.html#a964840d68d5d27ad2e16c63b4b2475b6", null ],
    [ "yyjson_mut_obj_rotate", "yyjson_8h.html#a0f1a9fea8fbc13caf61861dfdb498d46", null ],
    [ "yyjson_mut_obj_add_null", "yyjson_8h.html#a6efc657d7f9aefdcba51e753fcea02c1", null ],
    [ "yyjson_mut_obj_add_true", "yyjson_8h.html#a80380f14a448ea046eb718e068c2df6b", null ],
    [ "yyjson_mut_obj_add_false", "yyjson_8h.html#a52c88fea8622d7bf4e81ecea93dc5df6", null ],
    [ "yyjson_mut_obj_add_bool", "yyjson_8h.html#abe2f1b0c0b8cb9ceab3cdc35d4574c86", null ],
    [ "yyjson_mut_obj_add_uint", "yyjson_8h.html#a5f48e712fe4988f779a35309779dd765", null ],
    [ "yyjson_mut_obj_add_sint", "yyjson_8h.html#a4070a94fca9592eefa2798dd45237d85", null ],
    [ "yyjson_mut_obj_add_int", "yyjson_8h.html#a56726ff7e284700736e26e56afa6cf7b", null ],
    [ "yyjson_mut_obj_add_float", "yyjson_8h.html#aead391adc0e8fba55c0b230ac4d36612", null ],
    [ "yyjson_mut_obj_add_double", "yyjson_8h.html#a29d6ef8f7bf8135d9b7d93cb4c7d2c0c", null ],
    [ "yyjson_mut_obj_add_real", "yyjson_8h.html#aa4b243e9de837405d83bcc3251156cea", null ],
    [ "yyjson_mut_obj_add_str", "yyjson_8h.html#a996f8aa51f4c1475448974cf98f28df3", null ],
    [ "yyjson_mut_obj_add_strn", "yyjson_8h.html#a4530f9fc02f8604cef3de273feb4ab6a", null ],
    [ "yyjson_mut_obj_add_strcpy", "yyjson_8h.html#abeeca08e3b6994dddd55951a83cd648f", null ],
    [ "yyjson_mut_obj_add_strncpy", "yyjson_8h.html#a1d544048860a8c53510d560b4d60411a", null ],
    [ "yyjson_mut_obj_add_arr", "yyjson_8h.html#a1d27c9ad366209b83f236d74ec7e1991", null ],
    [ "yyjson_mut_obj_add_obj", "yyjson_8h.html#a7241260b7fefbbdfdf7566d207b486c5", null ],
    [ "yyjson_mut_obj_add_val", "yyjson_8h.html#a210aa96478b0b005b1611fe2f0ecbaa2", null ],
    [ "yyjson_mut_obj_remove_str", "yyjson_8h.html#a630b55e2937f7ffe8c0dcef20497ce93", null ],
    [ "yyjson_mut_obj_remove_strn", "yyjson_8h.html#ae6dfd237f7997125e606d678b3b59b5c", null ],
    [ "yyjson_mut_obj_rename_key", "yyjson_8h.html#aea65c64007cfa236faa17e1ac87c4e5e", null ],
    [ "yyjson_mut_obj_rename_keyn", "yyjson_8h.html#a335b9fdffa2885eb5eddd1ee2b43016b", null ],
    [ "yyjson_doc_ptr_get", "yyjson_8h.html#a9a9b30d275e211df9b84b91f4b95907a", null ],
    [ "yyjson_doc_ptr_getn", "yyjson_8h.html#a5b12a7b59d79123f9de71510efa2df3d", null ],
    [ "yyjson_doc_ptr_getx", "yyjson_8h.html#a53930a7b337295aefe993760fcc05645", null ],
    [ "yyjson_ptr_get", "yyjson_8h.html#a897cf07015f4f79fb4ebb0b3f58ac292", null ],
    [ "yyjson_ptr_getn", "yyjson_8h.html#aa3612af25f159df0c0587ddf8c7c58db", null ],
    [ "yyjson_ptr_getx", "yyjson_8h.html#a4b69d3a0061294fecd4a94927ad10e96", null ],
    [ "yyjson_mut_doc_ptr_get", "yyjson_8h.html#a5ad2700fe7073292adb71d508a049604", null ],
    [ "yyjson_mut_doc_ptr_getn", "yyjson_8h.html#a085db50b4cf005e489b7401281ea8636", null ],
    [ "yyjson_mut_doc_ptr_getx", "yyjson_8h.html#a6031b6b35b06127f3fa2278be67c29ea", null ],
    [ "yyjson_mut_ptr_get", "yyjson_8h.html#a8add57045c09758844b9433dbe3d4451", null ],
    [ "yyjson_mut_ptr_getn", "yyjson_8h.html#a7d72991b7e14b54845b639ef37c1c54c", null ],
    [ "yyjson_mut_ptr_getx", "yyjson_8h.html#abb1b3f84ca4f32c72dad8eea83f3d116", null ],
    [ "yyjson_mut_doc_ptr_add", "yyjson_8h.html#ae1a372cfbbc8a536decaf1db5223804d", null ],
    [ "yyjson_mut_doc_ptr_addn", "yyjson_8h.html#a5ee67bcb7012b25bd3bd7f88e5bb1699", null ],
    [ "yyjson_mut_doc_ptr_addx", "yyjson_8h.html#ad284e6ee4236ffa0be5d45625d57cac4", null ],
    [ "yyjson_mut_ptr_add", "yyjson_8h.html#ab49d3e532c97846b198b360602a9b5ca", null ],
    [ "yyjson_mut_ptr_addn", "yyjson_8h.html#aa65216783e9cd2ff949092399a2608d8", null ],
    [ "yyjson_mut_ptr_addx", "yyjson_8h.html#a256b4f50ed8e6830d57fbf7df7053141", null ],
    [ "yyjson_mut_doc_ptr_set", "yyjson_8h.html#a6c844108b8cdd6583802570b1500630c", null ],
    [ "yyjson_mut_doc_ptr_setn", "yyjson_8h.html#a222fa618ed3b7f6cbd355bb04708498f", null ],
    [ "yyjson_mut_doc_ptr_setx", "yyjson_8h.html#a48213b9742ba7fe6fb54b79be2da1f97", null ],
    [ "yyjson_mut_ptr_set", "yyjson_8h.html#a4de077663ebedc11a24ddbde66a72945", null ],
    [ "yyjson_mut_ptr_setn", "yyjson_8h.html#ac8ba98e62d5d4c5ab9ddd44173164756", null ],
    [ "yyjson_mut_ptr_setx", "yyjson_8h.html#a181de44520dcd7eb3211c617d10f4525", null ],
    [ "yyjson_mut_doc_ptr_replace", "yyjson_8h.html#a1a52947332757bebf28985bad6fb3d5d", null ],
    [ "yyjson_mut_doc_ptr_replacen", "yyjson_8h.html#a71d44a9f504b50eab96e59d348b2553f", null ],
    [ "yyjson_mut_doc_ptr_replacex", "yyjson_8h.html#aed5fc7ff1c73fd7a1829e863ce92ad65", null ],
    [ "yyjson_mut_ptr_replace", "yyjson_8h.html#ad617af11eb6bf81926531878f0117bba", null ],
    [ "yyjson_mut_ptr_replacen", "yyjson_8h.html#af324a76bd5e45899cccba7850d9ce43a", null ],
    [ "yyjson_mut_ptr_replacex", "yyjson_8h.html#a41f9c6e4641f813a7a94f12ea79b34ce", null ],
    [ "yyjson_mut_doc_ptr_remove", "yyjson_8h.html#a0358ed2cf421e64f5052068f41ca8f26", null ],
    [ "yyjson_mut_doc_ptr_removen", "yyjson_8h.html#a4ede66b0b130faa9af1c47878cf52be2", null ],
    [ "yyjson_mut_doc_ptr_removex", "yyjson_8h.html#a286f0920116870a3d27b466c515234a3", null ],
    [ "yyjson_mut_ptr_remove", "yyjson_8h.html#a853738b59790700627f7212b6e00922d", null ],
    [ "yyjson_mut_ptr_removen", "yyjson_8h.html#a3447370d5ab7657cd98c54ef17fb047b", null ],
    [ "yyjson_mut_ptr_removex", "yyjson_8h.html#a68a954cfda2a17cc612bb31460b902e1", null ],
    [ "yyjson_ptr_ctx_append", "yyjson_8h.html#aa0dcc48007c1754a4a181d81f22cb488", null ],
    [ "yyjson_ptr_ctx_replace", "yyjson_8h.html#ac61826dc8fd7fa6cafa58fa9a45d058e", null ],
    [ "yyjson_ptr_ctx_remove", "yyjson_8h.html#a92d8ec53e4cf8426288d86868dc89e09", null ],
    [ "yyjson_patch", "yyjson_8h.html#a2d0864410efdd15e4591fecc0b4c082c", null ],
    [ "yyjson_mut_patch", "yyjson_8h.html#ad4cca957150bd6f19fa12a4f907dffee", null ],
    [ "yyjson_merge_patch", "yyjson_8h.html#a9026faa4e022392c28e8f9afa553362f", null ],
    [ "yyjson_mut_merge_patch", "yyjson_8h.html#aad64266ebfbdd2a9627050cf1f3f48d7", null ],
    [ "yyjson_ptr_get_bool", "yyjson_8h.html#ac5d042e8760c46d5db48254a7740a48e", null ],
    [ "yyjson_ptr_get_uint", "yyjson_8h.html#a695d5d491618baa20d1f3258cf0fed8e", null ],
    [ "yyjson_ptr_get_sint", "yyjson_8h.html#a0b3d05df2a4e4748c75f35fa8ce8c650", null ],
    [ "yyjson_ptr_get_real", "yyjson_8h.html#a858ac36d7ad6a86e539cd84118498edb", null ],
    [ "yyjson_ptr_get_num", "yyjson_8h.html#a013cce9ecb58c53f0c3c9e1b081aa9c9", null ],
    [ "yyjson_ptr_get_str", "yyjson_8h.html#a177e25caf069be7e36b1ba17cad7dc7d", null ],
    [ "yyjson_deprecated", "yyjson_8h.html#a16058fb6568716afd9754100862d460d", null ],
    [ "yyjson_deprecated", "yyjson_8h.html#a5761a41e92b6f6ea1f5de114e36efb12", null ],
    [ "yyjson_deprecated", "yyjson_8h.html#a128b475e13bb4301babef4e03b9fda52", null ],
    [ "yyjson_deprecated", "yyjson_8h.html#a9c6dd96d063bacfa6413f7de90f90d91", null ],
    [ "yyjson_deprecated", "yyjson_8h.html#a2d26305e46b3a7f72619232805fa10c6", null ],
    [ "yyjson_deprecated", "yyjson_8h.html#a2acc549f8ce6bcac63ea89271b73d27a", null ],
    [ "yyjson_deprecated", "yyjson_8h.html#a84eb8968317b261a2e29528c1d8cf031", null ],
    [ "yyjson_deprecated", "yyjson_8h.html#a23d9715d999b1156d91adadeac913c32", null ],
    [ "yyjson_deprecated", "yyjson_8h.html#a1cea8f887599cb77d9394ecd07ae875e", null ],
    [ "yyjson_deprecated", "yyjson_8h.html#a779bd9e777e3a58d7e3ea5c6977d1965", null ],
    [ "YYJSON_READ_NOFLAG", "yyjson_8h.html#a8940a4ae4ba3467bb7bc6c5ee3deb2ea", null ],
    [ "YYJSON_READ_INSITU", "yyjson_8h.html#aa476cdc60442393b93dd0474ed4f08bc", null ],
    [ "YYJSON_READ_STOP_WHEN_DONE", "yyjson_8h.html#ad2fb99734b237a7af74924443fe5260e", null ],
    [ "YYJSON_READ_ALLOW_TRAILING_COMMAS", "yyjson_8h.html#a046c7832484dab943bed61ffac274e9c", null ],
    [ "YYJSON_READ_ALLOW_COMMENTS", "yyjson_8h.html#aff1d62b68993630e74355e4611b77520", null ],
    [ "YYJSON_READ_ALLOW_INF_AND_NAN", "yyjson_8h.html#a4b5c0a7092625f0324bccec938f8862f", null ],
    [ "YYJSON_READ_NUMBER_AS_RAW", "yyjson_8h.html#a1cafb3655e6e9e60f019d2b7a9bf79c2", null ],
    [ "YYJSON_READ_ALLOW_INVALID_UNICODE", "yyjson_8h.html#abdbf139ee03d263c8a833fbef8cbf63c", null ],
    [ "YYJSON_READ_BIGNUM_AS_RAW", "yyjson_8h.html#a305e109d45b8e2b419b7266b839dffa0", null ],
    [ "YYJSON_READ_ALLOW_BOM", "yyjson_8h.html#af1d965029a44a6a65b9ef3f9a4ccbc09", null ],
    [ "YYJSON_READ_ALLOW_EXT_NUMBER", "yyjson_8h.html#a17429af07c44e8d9b3f6083df78e2ab1", null ],
    [ "YYJSON_READ_ALLOW_EXT_ESCAPE", "yyjson_8h.html#aa0ef136f329e2b6016ceddf508e2d996", null ],
    [ "YYJSON_READ_ALLOW_EXT_WHITESPACE", "yyjson_8h.html#a63f7c53c14f9de30d222acaa287eb490", null ],
    [ "YYJSON_READ_ALLOW_SINGLE_QUOTED_STR", "yyjson_8h.html#ade31e55bb9edddbaf2cd5c0c0ba03c64", null ],
    [ "YYJSON_READ_ALLOW_UNQUOTED_KEY", "yyjson_8h.html#a38be7a9df2511df7d72b678379d7ca01", null ],
    [ "YYJSON_READ_JSON5", "yyjson_8h.html#a8618ef9d06392f4267d853d8c0986319", null ],
    [ "YYJSON_READ_SUCCESS", "yyjson_8h.html#a5b8948d47748a81d6a4abf94949e0e88", null ],
    [ "YYJSON_READ_ERROR_INVALID_PARAMETER", "yyjson_8h.html#a841a5fd5b187b1ff40232e9d36a5a156", null ],
    [ "YYJSON_READ_ERROR_MEMORY_ALLOCATION", "yyjson_8h.html#a0b729e2b5afc21914a723897dda10c3f", null ],
    [ "YYJSON_READ_ERROR_EMPTY_CONTENT", "yyjson_8h.html#ad8eeaba5611ace5817c7019067cf85fd", null ],
    [ "YYJSON_READ_ERROR_UNEXPECTED_CONTENT", "yyjson_8h.html#a0d42ebb09b02ed4e579938b96a833070", null ],
    [ "YYJSON_READ_ERROR_UNEXPECTED_END", "yyjson_8h.html#ae82405796b54b235125a5dd14c06650b", null ],
    [ "YYJSON_READ_ERROR_UNEXPECTED_CHARACTER", "yyjson_8h.html#aec30d870399447d1b611c400dff5a55c", null ],
    [ "YYJSON_READ_ERROR_JSON_STRUCTURE", "yyjson_8h.html#ad5bf7b51ed21d3c99500a8f488b2b4b0", null ],
    [ "YYJSON_READ_ERROR_INVALID_COMMENT", "yyjson_8h.html#a70209d60e93b24573e8830911c7940a6", null ],
    [ "YYJSON_READ_ERROR_INVALID_NUMBER", "yyjson_8h.html#a8f8b24bb3b8dafc3f135a926b06da2fa", null ],
    [ "YYJSON_READ_ERROR_INVALID_STRING", "yyjson_8h.html#ab4f2d4e7fa716c89d3a31f74504898a9", null ],
    [ "YYJSON_READ_ERROR_LITERAL", "yyjson_8h.html#a18810c64371c556ea42c0addb9e25bdc", null ],
    [ "YYJSON_READ_ERROR_FILE_OPEN", "yyjson_8h.html#a76cb39cc0755460feedaf3fcf32cea01", null ],
    [ "YYJSON_READ_ERROR_FILE_READ", "yyjson_8h.html#a2cea1aba7baff98fee5affd7737fc969", null ],
    [ "YYJSON_READ_ERROR_MORE", "yyjson_8h.html#a48706a3eb7761926a6c0ec3239dda76c", null ],
    [ "YYJSON_WRITE_NOFLAG", "yyjson_8h.html#ae152a6e8e8c6e4efd798fa6eca9d311f", null ],
    [ "YYJSON_WRITE_PRETTY", "yyjson_8h.html#aebdaa55a1673e99d2dcea01a15c633be", null ],
    [ "YYJSON_WRITE_ESCAPE_UNICODE", "yyjson_8h.html#ac234e82f7a1203e656bcbb0af2ce8c01", null ],
    [ "YYJSON_WRITE_ESCAPE_SLASHES", "yyjson_8h.html#a0eeb35b40e688fce9dd61ed400984042", null ],
    [ "YYJSON_WRITE_ALLOW_INF_AND_NAN", "yyjson_8h.html#a38fa90e4cf75b0a78148de2058c1b3bd", null ],
    [ "YYJSON_WRITE_INF_AND_NAN_AS_NULL", "yyjson_8h.html#a4408e0c5928db936b89d49ccf255100b", null ],
    [ "YYJSON_WRITE_ALLOW_INVALID_UNICODE", "yyjson_8h.html#ae2709fd5ec704ef7a569d62195e4652d", null ],
    [ "YYJSON_WRITE_PRETTY_TWO_SPACES", "yyjson_8h.html#a7b13411e137d8085b68b2e0fc9d6736b", null ],
    [ "YYJSON_WRITE_NEWLINE_AT_END", "yyjson_8h.html#ab0cfae40d7ae6489d73c6cf5db9c09e1", null ],
    [ "YYJSON_WRITE_SUCCESS", "yyjson_8h.html#a20d8f66fbe535a20596001dc2022f0b4", null ],
    [ "YYJSON_WRITE_ERROR_INVALID_PARAMETER", "yyjson_8h.html#a7f123c4c3d850fd6c4e46a2b3aad4508", null ],
    [ "YYJSON_WRITE_ERROR_MEMORY_ALLOCATION", "yyjson_8h.html#a4d515d2d192d13281ffe69c1d95cdd49", null ],
    [ "YYJSON_WRITE_ERROR_INVALID_VALUE_TYPE", "yyjson_8h.html#a40c9783509f730cb3ef67080be9444d8", null ],
    [ "YYJSON_WRITE_ERROR_NAN_OR_INF", "yyjson_8h.html#a179477749cf2aa26c0841089debe4756", null ],
    [ "YYJSON_WRITE_ERROR_FILE_OPEN", "yyjson_8h.html#a41cb8e304e08d7455f43c753bfa19b82", null ],
    [ "YYJSON_WRITE_ERROR_FILE_WRITE", "yyjson_8h.html#a7910a72a728d4f245d43417a42e2e91a", null ],
    [ "YYJSON_WRITE_ERROR_INVALID_STRING", "yyjson_8h.html#ab8f221edd44b0c61d9ff78637bfca05e", null ],
    [ "YYJSON_PTR_ERR_NONE", "yyjson_8h.html#a41a31c0ddcce2b75cacb5fd2375d1ca7", null ],
    [ "YYJSON_PTR_ERR_PARAMETER", "yyjson_8h.html#a2aafb20a8b3f52a085880c262edf9264", null ],
    [ "YYJSON_PTR_ERR_SYNTAX", "yyjson_8h.html#a4eb15db0deb14f592e8d6966fd0af261", null ],
    [ "YYJSON_PTR_ERR_RESOLVE", "yyjson_8h.html#affa45e3752beb609cb0b2fa159d1d319", null ],
    [ "YYJSON_PTR_ERR_NULL_ROOT", "yyjson_8h.html#a5c8d7b159d5eede673be0c9b93897abb", null ],
    [ "YYJSON_PTR_ERR_SET_ROOT", "yyjson_8h.html#af8eda6e0f4e8aaedd0f410481c7c13d6", null ],
    [ "YYJSON_PTR_ERR_MEMORY_ALLOCATION", "yyjson_8h.html#ac33bbc34a7aa3d634e3ba5794521f67d", null ],
    [ "YYJSON_PATCH_SUCCESS", "yyjson_8h.html#a2f1611858d54b9a1a52b66337bc5e0c9", null ],
    [ "YYJSON_PATCH_ERROR_INVALID_PARAMETER", "yyjson_8h.html#a10037da4811bc7822093e9417a738c27", null ],
    [ "YYJSON_PATCH_ERROR_MEMORY_ALLOCATION", "yyjson_8h.html#ad764ba2c4bd7d5da4107c46482871bcc", null ],
    [ "YYJSON_PATCH_ERROR_INVALID_OPERATION", "yyjson_8h.html#a39f7a03e87df8d89482c15e5c6575ef3", null ],
    [ "YYJSON_PATCH_ERROR_MISSING_KEY", "yyjson_8h.html#a5e724ca36dfc1f6cce285be9e0c1953a", null ],
    [ "YYJSON_PATCH_ERROR_INVALID_MEMBER", "yyjson_8h.html#a1529e42ade3c00f0b513f6cb6d722f22", null ],
    [ "YYJSON_PATCH_ERROR_EQUAL", "yyjson_8h.html#adb43ed842536ac6e5ac17f5f693992be", null ],
    [ "YYJSON_PATCH_ERROR_POINTER", "yyjson_8h.html#a6e43e19e2920e8d3725372efb98c3aad", null ]
];